"""Util functions for tests."""

from lightly_purple.server.routes.api.status import HTTP_STATUS_CREATED


def create_dataset(client):
    """Helper function to create a dataset and return its ID."""
    new_dataset_result = client.post(
        "/api/datasets",
        json={
            "dataset_id": None,
            "name": "string",
            "directory": "string",
            "created_at": None,
            "updated_at": None,
        },
    )
    assert new_dataset_result.status_code == HTTP_STATUS_CREATED
    return new_dataset_result.json()["dataset_id"]


def create_sample(
    client,
    dataset_id,
    file_path_abs="/path/to/sample1.png",
):
    """Helper function to create a sample and return its ID."""
    input_sample = {
        "sample_id": None,
        "dataset_id": dataset_id,
        "width": 12,
        "height": 1,
        "file_name": "sample.jpg",
        "created_at": None,
        "updated_at": None,
        "file_path_abs": file_path_abs,
    }
    new_sample_result = client.post(
        "/api/samples",
        json=input_sample,
    )
    assert new_sample_result.status_code == HTTP_STATUS_CREATED
    return new_sample_result.json()["sample_id"], input_sample


def create_annotation(client, sample_id, annotation_label_id):
    """Helper function to create an annotation and return its ID."""
    input_annotation = {
        "annotation_id": None,
        "sample_id": str(sample_id),
        "annotation_label_id": str(annotation_label_id),
        "x": 0.5,
        "y": 0.5,
        "width": 1.0,
        "height": 1.0,
    }
    new_annotation_result = client.post(
        "/api/annotations",
        json=input_annotation,
    )
    assert new_annotation_result.status_code == HTTP_STATUS_CREATED
    return new_annotation_result.json()["annotation_id"], input_annotation


def create_annotation_label(client):
    """Helper function to create an annotation label and return its ID."""
    label_data = {
        "annotation_label_name": "example_label",  # Provide a label name
    }
    response = client.post("/api/annotation_labels", json=label_data)
    assert response.status_code == HTTP_STATUS_CREATED
    return response.json()["annotation_label_id"]
